SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

DROP SCHEMA IF EXISTS `SCET` ;
CREATE SCHEMA IF NOT EXISTS `SCET` DEFAULT CHARACTER SET utf8 ;
USE `SCET` ;

-- -----------------------------------------------------
-- Table `SCET`.`Objetos`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Objetos` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Objetos` (
  `idObjetos` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `referencia` VARCHAR(50) NULL DEFAULT NULL ,
  `nombre` VARCHAR(100) NULL DEFAULT NULL ,
  `descripcion` MEDIUMTEXT NULL ,
  PRIMARY KEY (`idObjetos`) ,
  UNIQUE INDEX `referencia_UNIQUE` (`referencia` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Ubicaciones`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Ubicaciones` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Ubicaciones` (
  `idUbicaciones` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `referencia` VARCHAR(50) NULL DEFAULT NULL ,
  `nombre` VARCHAR(100) NULL DEFAULT NULL ,
  `descripcion` MEDIUMTEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`idUbicaciones`) ,
  UNIQUE INDEX `referencia_UNIQUE` (`referencia` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Entidades`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Entidades` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Entidades` (
  `idEntidades` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `referencia` VARCHAR(50) NULL DEFAULT NULL ,
  `nombre` VARCHAR(100) NULL DEFAULT NULL ,
  PRIMARY KEY (`idEntidades`) ,
  UNIQUE INDEX `ref_UNIQUE` (`referencia` ASC) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Empresas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Empresas` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Empresas` (
  `idEmpresas` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntidades` INT UNSIGNED NOT NULL ,
  `idUbicaciones` INT UNSIGNED NOT NULL ,
  PRIMARY KEY (`idEmpresas`, `idEntidades`, `idUbicaciones`) ,
  INDEX `fk_Empresas_Entidades` (`idEntidades` ASC) ,
  INDEX `fk_Empresas_Ubicaciones` (`idUbicaciones` ASC) ,
  CONSTRAINT `fk_Empresas_Entidades`
    FOREIGN KEY (`idEntidades` )
    REFERENCES `SCET`.`Entidades` (`idEntidades` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Empresas_Ubicaciones`
    FOREIGN KEY (`idUbicaciones` )
    REFERENCES `SCET`.`Ubicaciones` (`idUbicaciones` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Talleres`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Talleres` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Talleres` (
  `idTalleres` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idUbicaciones` INT UNSIGNED NOT NULL ,
  `idEmpresas` INT UNSIGNED NULL ,
  PRIMARY KEY (`idTalleres`, `idUbicaciones`) ,
  INDEX `fk_Talleres_Ubicaciones` (`idUbicaciones` ASC) ,
  INDEX `fk_Talleres_Empresas` (`idEmpresas` ASC) ,
  CONSTRAINT `fk_Talleres_Ubicaciones`
    FOREIGN KEY (`idUbicaciones` )
    REFERENCES `SCET`.`Ubicaciones` (`idUbicaciones` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Talleres_Empresas`
    FOREIGN KEY (`idEmpresas` )
    REFERENCES `SCET`.`Empresas` (`idEmpresas` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Caracteristicas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Caracteristicas` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Caracteristicas` (
  `idCaracteristicas` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntidades` INT UNSIGNED NOT NULL ,
  `tipo` VARCHAR(50) NOT NULL ,
  `valor` MEDIUMTEXT NULL DEFAULT NULL ,
  `actualisacion` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`idCaracteristicas`) ,
  INDEX `fk_Caracteristicas_Entidades` (`idEntidades` ASC) ,
  CONSTRAINT `fk_Caracteristicas_Entidades`
    FOREIGN KEY (`idEntidades` )
    REFERENCES `SCET`.`Entidades` (`idEntidades` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Especificaciones`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Especificaciones` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Especificaciones` (
  `idEspecificaciones` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idObjetos` INT UNSIGNED NOT NULL ,
  `tipo` VARCHAR(50) NOT NULL ,
  `valor` MEDIUMTEXT NULL DEFAULT NULL ,
  `actualisacion` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`idEspecificaciones`) ,
  INDEX `fk_Caracateristicas_Equipos` (`idObjetos` ASC) ,
  CONSTRAINT `fk_Caracateristicas_Equipos`
    FOREIGN KEY (`idObjetos` )
    REFERENCES `SCET`.`Objetos` (`idObjetos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Tecnicos`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Tecnicos` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Tecnicos` (
  `idTecnicos` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntidades` INT UNSIGNED NOT NULL ,
  `idEmpresas` INT UNSIGNED NULL ,
  PRIMARY KEY (`idTecnicos`, `idEntidades`) ,
  INDEX `fk_Tecnicos_Entidades` (`idEntidades` ASC) ,
  INDEX `fk_Tecnicos_Empresas` (`idEmpresas` ASC) ,
  CONSTRAINT `fk_Tecnicos_Entidades`
    FOREIGN KEY (`idEntidades` )
    REFERENCES `SCET`.`Entidades` (`idEntidades` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Tecnicos_Empresas`
    FOREIGN KEY (`idEmpresas` )
    REFERENCES `SCET`.`Empresas` (`idEmpresas` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Descripciones`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Descripciones` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Descripciones` (
  `idDescripciones` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idUbicaciones` INT UNSIGNED NOT NULL ,
  `tipo` VARCHAR(50) NOT NULL ,
  `valor` MEDIUMTEXT NULL ,
  `actualisacion` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`idDescripciones`) ,
  INDEX `fk_Descripciones_Ubicaciones` (`idUbicaciones` ASC) ,
  CONSTRAINT `fk_Descripciones_Ubicaciones`
    FOREIGN KEY (`idUbicaciones` )
    REFERENCES `SCET`.`Ubicaciones` (`idUbicaciones` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Almasenes`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Almasenes` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Almasenes` (
  `idAlmasenes` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idUbicaciones` INT UNSIGNED NOT NULL ,
  `idEmpresas` INT UNSIGNED NULL ,
  PRIMARY KEY (`idAlmasenes`, `idUbicaciones`) ,
  INDEX `fk_Almasenes_Ubicaciones` (`idUbicaciones` ASC) ,
  INDEX `fk_Almasenes_Empresas` (`idEmpresas` ASC) ,
  CONSTRAINT `fk_Almasenes_Ubicaciones`
    FOREIGN KEY (`idUbicaciones` )
    REFERENCES `SCET`.`Ubicaciones` (`idUbicaciones` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Almasenes_Empresas`
    FOREIGN KEY (`idEmpresas` )
    REFERENCES `SCET`.`Empresas` (`idEmpresas` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Herramientas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Herramientas` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Herramientas` (
  `idHerramientas` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idObjetos` INT UNSIGNED NOT NULL ,
  `idEmpresas` INT UNSIGNED NULL ,
  PRIMARY KEY (`idHerramientas`, `idObjetos`) ,
  INDEX `fk_Herramientas_Equipos` (`idObjetos` ASC) ,
  INDEX `fk_Herramientas_Empresas` (`idEmpresas` ASC) ,
  CONSTRAINT `fk_Herramientas_Equipos`
    FOREIGN KEY (`idObjetos` )
    REFERENCES `SCET`.`Objetos` (`idObjetos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Herramientas_Empresas`
    FOREIGN KEY (`idEmpresas` )
    REFERENCES `SCET`.`Empresas` (`idEmpresas` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Clientes`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Clientes` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Clientes` (
  `idClientes` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntidades` INT UNSIGNED NOT NULL ,
  `idUbicaciones` INT UNSIGNED NULL ,
  PRIMARY KEY (`idClientes`, `idEntidades`) ,
  INDEX `fk_Clientes_Entidades` (`idEntidades` ASC) ,
  INDEX `fk_Clientes_Ubicaciones` (`idUbicaciones` ASC) ,
  CONSTRAINT `fk_Clientes_Entidades`
    FOREIGN KEY (`idEntidades` )
    REFERENCES `SCET`.`Entidades` (`idEntidades` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Clientes_Ubicaciones`
    FOREIGN KEY (`idUbicaciones` )
    REFERENCES `SCET`.`Ubicaciones` (`idUbicaciones` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Entradas`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Entradas` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Entradas` (
  `idEntradas` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `refenrencia` VARCHAR(50) NULL DEFAULT NULL ,
  `idEmpresas` INT UNSIGNED NOT NULL ,
  `idClientes` INT UNSIGNED NOT NULL ,
  `fecha_entrada` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ,
  `fecha_salida` TIMESTAMP NULL DEFAULT NULL ,
  `estado` TINYINT(1) NOT NULL DEFAULT 0 COMMENT '0: En Proseso\n1: Terminado' ,
  PRIMARY KEY (`idEntradas`) ,
  UNIQUE INDEX `refenrencia_UNIQUE` (`refenrencia` ASC) ,
  INDEX `fk_Entradas_Empresas` (`idEmpresas` ASC) ,
  INDEX `fk_Entradas_Clientes` (`idClientes` ASC) ,
  CONSTRAINT `fk_Entradas_Empresas`
    FOREIGN KEY (`idEmpresas` )
    REFERENCES `SCET`.`Empresas` (`idEmpresas` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Entradas_Clientes`
    FOREIGN KEY (`idClientes` )
    REFERENCES `SCET`.`Clientes` (`idClientes` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Equipos`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Equipos` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Equipos` (
  `idEquipos` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idObjetos` INT UNSIGNED NOT NULL ,
  `idClientes` INT UNSIGNED NULL ,
  PRIMARY KEY (`idEquipos`, `idObjetos`) ,
  INDEX `fk_Equipos_Objetos` (`idObjetos` ASC) ,
  INDEX `fk_Equipos_Clientes` (`idClientes` ASC) ,
  CONSTRAINT `fk_Equipos_Objetos`
    FOREIGN KEY (`idObjetos` )
    REFERENCES `SCET`.`Objetos` (`idObjetos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Equipos_Clientes`
    FOREIGN KEY (`idClientes` )
    REFERENCES `SCET`.`Clientes` (`idClientes` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Entrada_Equipos`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Entrada_Equipos` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Entrada_Equipos` (
  `idEntrada_Equipos` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntradas` INT UNSIGNED NOT NULL ,
  `idEquipos` INT UNSIGNED NOT NULL ,
  `idTalleres` INT UNSIGNED NULL ,
  `dAlmasenes` INT UNSIGNED NULL ,
  `estado` TINYINT(1) NOT NULL DEFAULT 0 COMMENT '0: En proceso\n1: Terminado' ,
  INDEX `fk_Entradas_has_Equipos_Entradas1` (`idEntradas` ASC) ,
  PRIMARY KEY (`idEntrada_Equipos`) ,
  INDEX `fk_Entrada_Equipos_Talleres` (`idTalleres` ASC) ,
  INDEX `fk_Entrada_Equipos_Almasenes` (`dAlmasenes` ASC) ,
  INDEX `fk_Entrada_Equipos_Equipos` (`idEquipos` ASC) ,
  CONSTRAINT `fk_Entrada_Equipos_Entradas`
    FOREIGN KEY (`idEntradas` )
    REFERENCES `SCET`.`Entradas` (`idEntradas` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Entrada_Equipos_Talleres`
    FOREIGN KEY (`idTalleres` )
    REFERENCES `SCET`.`Talleres` (`idTalleres` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Entrada_Equipos_Almasenes`
    FOREIGN KEY (`dAlmasenes` )
    REFERENCES `SCET`.`Almasenes` (`idAlmasenes` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Entrada_Equipos_Equipos`
    FOREIGN KEY (`idEquipos` )
    REFERENCES `SCET`.`Equipos` (`idEquipos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Acciones`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Acciones` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Acciones` (
  `idAcciones` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `fecha` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
  `idEntrada_Equipos` INT UNSIGNED NOT NULL ,
  `descripcion` MEDIUMTEXT NULL ,
  PRIMARY KEY (`idAcciones`) ,
  INDEX `fk_Acciones_Entrada_Equipos1` (`idEntrada_Equipos` ASC) ,
  CONSTRAINT `fk_Acciones_Entrada_Equipos10`
    FOREIGN KEY (`idEntrada_Equipos` )
    REFERENCES `SCET`.`Entrada_Equipos` (`idEntrada_Equipos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Tecnicos_Entrada_Equipos`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Tecnicos_Entrada_Equipos` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Tecnicos_Entrada_Equipos` (
  `idTecnicos_Entrada_Equipos` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idTecnicos` INT UNSIGNED NOT NULL ,
  `idEntrada_Equipos` INT UNSIGNED NOT NULL ,
  INDEX `fk_Tecnicos_Entrada_Equipos_Entrada_Equipos` (`idEntrada_Equipos` ASC) ,
  INDEX `fk_Tecnicos_Entrada_Equipos_Tecnicos` (`idTecnicos` ASC) ,
  PRIMARY KEY (`idTecnicos_Entrada_Equipos`) ,
  CONSTRAINT `fk_Tecnicos_Entrada_Equipos_Tecnicos`
    FOREIGN KEY (`idTecnicos` )
    REFERENCES `SCET`.`Tecnicos` (`idTecnicos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `fk_Tecnicos_Entrada_Equipos_Entrada_Equipos`
    FOREIGN KEY (`idEntrada_Equipos` )
    REFERENCES `SCET`.`Entrada_Equipos` (`idEntrada_Equipos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Contacto`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Contacto` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Contacto` (
  `idContacto` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntidades` INT UNSIGNED NOT NULL ,
  `tipo` VARCHAR(50) NULL ,
  `valor` VARCHAR(100) NULL ,
  PRIMARY KEY (`idContacto`) ,
  INDEX `fk_Contacto_Entidades1` (`idEntidades` ASC) ,
  CONSTRAINT `fk_Contacto_Entidades1`
    FOREIGN KEY (`idEntidades` )
    REFERENCES `SCET`.`Entidades` (`idEntidades` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SCET`.`Informacion_Fiscal`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SCET`.`Informacion_Fiscal` ;

CREATE  TABLE IF NOT EXISTS `SCET`.`Informacion_Fiscal` (
  `idInformacion_Fiscal` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idEntidades` INT UNSIGNED NOT NULL ,
  `razon_social` VARCHAR(100) NULL ,
  `rif_tipo` CHAR(1) NULL ,
  `rif_numero` DECIMAL(8) NULL ,
  `rif_final` DECIMAL(1) NULL ,
  `estado` VARCHAR(50) NULL ,
  `ciudad` VARCHAR(50) NULL ,
  `direccion` MEDIUMTEXT NULL ,
  PRIMARY KEY (`idInformacion_Fiscal`) ,
  INDEX `fk_Informacion_fiscal_Entidades1` (`idEntidades` ASC) ,
  CONSTRAINT `fk_Informacion_fiscal_Entidades1`
    FOREIGN KEY (`idEntidades` )
    REFERENCES `SCET`.`Entidades` (`idEntidades` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Talleres`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Talleres` (`idTalleres` INT, `nombre` INT, `referencia` INT, `descripcion` INT, `idEmpresas` INT, `idUbicaciones` INT);

-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Tecnicos`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Tecnicos` (`idTecnicos` INT, `nombre` INT, `referencia` INT, `idEmpresas` INT, `idEntidades` INT);

-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Almasenes`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Almasenes` (`idAlmasenes` INT, `nombre` INT, `referencia` INT, `descripcion` INT, `idEmpresas` INT, `idUbicaciones` INT);

-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Herramientas`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Herramientas` (`idHerramientas` INT, `nombre` INT, `referencia` INT, `descripcion` INT, `idEmpresas` INT, `idObjetos` INT);

-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Clientes`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Clientes` (`idClientes` INT, `idEntidades` INT, `nombre` INT, `referencia` INT, `idUbicaciones` INT, `ubicacion` INT);

-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Equipos`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Equipos` (`idEquipos` INT, `idObjetos` INT, `nombre` INT, `referencia` INT, `descripcion` INT, `idClientes` INT);

-- -----------------------------------------------------
-- Placeholder table for view `SCET`.`_Empresas`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `SCET`.`_Empresas` (`idEmpresas` INT, `idEntidades` INT, `nombre` INT, `referencia` INT, `idUbicaciones` INT, `ubicacion` INT);

-- -----------------------------------------------------
-- View `SCET`.`_Talleres`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Talleres` ;
DROP TABLE IF EXISTS `SCET`.`_Talleres`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Talleres` AS
SELECT 
    `a`.`idTalleres`,
    `b`.`nombre`,
    `b`.`referencia`,
    `b`.`descripcion`,
    `a`.`idEmpresas`,
    `b`.`idUbicaciones`
FROM `Talleres` AS `a` 
LEFT JOIN `Ubicaciones` AS `b` ON (`a`.`idUbicaciones` = `b`.`idUbicaciones`);

-- -----------------------------------------------------
-- View `SCET`.`_Tecnicos`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Tecnicos` ;
DROP TABLE IF EXISTS `SCET`.`_Tecnicos`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Tecnicos` AS
SELECT 
    `a`.`idTecnicos`,
    `b`.`nombre`,
    `b`.`referencia`,
    `a`.`idEmpresas`,
    `b`.`idEntidades`
FROM `Tecnicos` AS `a` 
LEFT JOIN `Entidades` AS `b` ON (`a`.`idEntidades` = `b`.`idEntidades`);

-- -----------------------------------------------------
-- View `SCET`.`_Almasenes`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Almasenes` ;
DROP TABLE IF EXISTS `SCET`.`_Almasenes`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Almasenes` AS
SELECT 
    `a`.`idAlmasenes`,
    `b`.`nombre`,
    `b`.`referencia`,
    `b`.`descripcion`,
    `a`.`idEmpresas`,
    `b`.`idUbicaciones`
FROM `Almasenes` AS `a` 
LEFT JOIN `Ubicaciones` AS `b` ON (`a`.`idUbicaciones` = `b`.`idUbicaciones`);

-- -----------------------------------------------------
-- View `SCET`.`_Herramientas`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Herramientas` ;
DROP TABLE IF EXISTS `SCET`.`_Herramientas`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Herramientas` AS
SELECT 
    `a`.`idHerramientas`,
    `b`.`nombre`,
    `b`.`referencia`,
    `b`.`descripcion`,
    `a`.`idEmpresas`,
    `b`.`idObjetos`
FROM `Herramientas` AS `a` 
LEFT JOIN `Objetos` AS `b` ON (`a`.`idObjetos` = `b`.`idObjetos`);

-- -----------------------------------------------------
-- View `SCET`.`_Clientes`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Clientes` ;
DROP TABLE IF EXISTS `SCET`.`_Clientes`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Clientes` AS
SELECT 
    `a`.`idClientes`,
    `b`.`idEntidades`,
    `b`.`nombre`,
    `b`.`referencia`,
    `c`.`idUbicaciones`,
    `c`.`descripcion` as `ubicacion`
FROM `Clientes` AS `a` 
LEFT JOIN `Entidades` AS `b` ON (`a`.`idEntidades` = `b`.`idEntidades`)
LEFT JOIN `Ubicaciones` AS `c` ON (`a`.`idUbicaciones` = `c`.`idUbicaciones`);

-- -----------------------------------------------------
-- View `SCET`.`_Equipos`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Equipos` ;
DROP TABLE IF EXISTS `SCET`.`_Equipos`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Equipos` AS
SELECT 
    `a`.`idEquipos`,
    `b`.`idObjetos`,
    `b`.`nombre`,
    `b`.`referencia`,
    `b`.`descripcion`,
    `a`.`idClientes`
FROM `Equipos` AS `a` 
LEFT JOIN `Objetos` AS `b` ON (`a`.`idObjetos` = `b`.`idObjetos`);

-- -----------------------------------------------------
-- View `SCET`.`_Empresas`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `SCET`.`_Empresas` ;
DROP TABLE IF EXISTS `SCET`.`_Empresas`;
USE `SCET`;
CREATE  OR REPLACE VIEW `SCET`.`_Empresas` AS
SELECT 
    `a`.`idEmpresas`,
    `b`.`idEntidades`,
    `b`.`nombre`,
    `b`.`referencia`,
    `c`.`idUbicaciones`,
    `c`.`descripcion` as `ubicacion`
FROM `Empresas` AS `a` 
LEFT JOIN `Entidades` AS `b` ON (`a`.`idEntidades` = `b`.`idEntidades`)
LEFT JOIN `Ubicaciones` AS `c` ON (`a`.`idUbicaciones` = `c`.`idUbicaciones`);


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
